@@ -561,7 +561,7 @@ class DataLabelling:
                 status,
                 status_description,
             )
-            url = "/v1/project/action"
+            url = "/v1/actions"
             payload = {
                 "_id": self.action_record_id,
                 "action": self.action_type,
