@@ -261,12 +261,30 @@ class ColorDetectionUseCase(BaseProcessor):
             cat = det.get('category')
             color = det.get('main_color')
             track_id = det.get('track_id')
-            if cat and color and track_id is not None:
-                key = f"{cat}:{color}"  # Unique key for category-color pair
+            if cat and track_id is not None:
+                # If color not yet computed at this stage, fall back to category-only key
+                key = f"{cat}:{color}" if color else cat
                 self._color_total_track_ids[key].add(track_id)
                 self._color_current_frame_track_ids[key].add(track_id)
 
     def get_total_color_counts(self):
+        """Return total unique track_id count per color (across all categories)."""
+        store = getattr(self, '_color_total_track_ids', {})
+        if not isinstance(store, dict):
+            return {}
+        color_to_ids = defaultdict(set)
+        for key, id_set in store.items():
+            if isinstance(key, str) and ':' in key:
+                _, color = key.split(':', 1)
+            else:
+                color = None
+            # Support both set and iterable
+            ids = id_set if isinstance(id_set, set) else set(id_set or [])
+            if color:
+                color_to_ids[color].update(ids)
+        return {color: len(ids) for color, ids in color_to_ids.items()}
+
+    def get_total_category_counts(self):
         """Return total unique track_id count per category (across all colors)."""
         store = getattr(self, '_color_total_track_ids', {})
         if not isinstance(store, dict):
@@ -277,7 +295,6 @@ class ColorDetectionUseCase(BaseProcessor):
                 cat, _ = key.split(':', 1)
             else:
                 cat = key
-            # Support both set and iterable
             ids = id_set if isinstance(id_set, set) else set(id_set or [])
             category_to_ids[cat].update(ids)
         return {cat: len(ids) for cat, ids in category_to_ids.items()}
@@ -419,10 +436,25 @@ class ColorDetectionUseCase(BaseProcessor):
             print("-------------------COLOR_ANALYSIS-------------------")
             
             # Step 8: Calculate summaries
+            # After color extraction, update cumulative color-aware tracking totals
+            self._update_color_tracking_state_from_analysis(color_analysis)
             color_summary = self._calculate_color_summary(color_analysis, config)
+            # Ensure total_color_counts is populated even on first frame/session
+            totals = self.get_total_color_counts()
+            if not totals:
+                tmp = defaultdict(set)
+                for rec in color_analysis:
+                    color = rec.get('main_color')
+                    tid = rec.get('track_id') or rec.get('detection_id')
+                    if color and tid is not None:
+                        tmp[color].add(tid)
+                totals = {color: len(ids) for color, ids in tmp.items()}
+            # Also compute total per-category counts
+            total_category_counts = self.get_total_category_counts()
             
             general_summary = self._calculate_general_summary(processed_data, config)
-            color_summary['total_color_counts'] = self.get_total_color_counts()
+            color_summary['total_color_counts'] = totals
+            color_summary['total_category_counts'] = total_category_counts
             print("-------------------COLOR_SUMMARY-------------------")
             print(color_summary)
             print("-------------------COLOR_SUMMARY-------------------")
@@ -511,6 +543,25 @@ class ColorDetectionUseCase(BaseProcessor):
             return self._analyze_colors_in_video(data, media_bytes, config)
         else:
             return self._analyze_colors_in_image(data, media_bytes, config)
+
+    def _update_color_tracking_state_from_analysis(self, color_analysis: List[Dict[str, Any]]) -> None:
+        """Update total tracking store using analyzed color results.
+        Ensures totals are populated even if pre-analysis detections lacked colors/track_ids."""
+        existing_store = getattr(self, '_color_total_track_ids', None)
+        if not isinstance(existing_store, defaultdict):
+            existing_store = {} if existing_store is None else dict(existing_store)
+            self._color_total_track_ids = defaultdict(set, existing_store)
+        else:
+            self._color_total_track_ids = existing_store
+        for rec in color_analysis:
+            cat = rec.get('category')
+            color = rec.get('main_color')
+            track_id = rec.get('track_id')
+            if track_id is None:
+                track_id = rec.get('detection_id')
+            if cat and track_id is not None:
+                key = f"{cat}:{color}" if color else cat
+                self._color_total_track_ids[key].add(track_id)
     
     def _is_video_bytes(self, media_bytes: bytes) -> bool:
         """Determine if bytes represent a video file."""
@@ -946,10 +997,18 @@ class ColorDetectionUseCase(BaseProcessor):
         tracking_stats = []
 
         total_detections = counting_summary.get("total_count", 0)
-        total_counts = counting_summary.get("total_color_counts", {})
-        cumulative_total = sum(total_counts.values()) if total_counts else 0
+        total_color_counts_dict = counting_summary.get("total_color_counts", {})
+        total_category_counts_dict = counting_summary.get("total_category_counts", {})
+        cumulative_total = sum(total_color_counts_dict.values()) if total_color_counts_dict else 0
         per_category_count = counting_summary.get("per_category_count", {})
 
+        # Compute current color counts from detections
+        current_color_count: Dict[str, int] = {}
+        for det in counting_summary.get("detections", []):
+            color = det.get("main_color")
+            if color:
+                current_color_count[color] = current_color_count.get(color, 0) + 1
+
         track_ids_info = self._get_track_ids_info(counting_summary.get("detections", []))
 
         current_timestamp = self._get_current_timestamp_str(stream_info, precision=False)
@@ -965,6 +1024,7 @@ class ColorDetectionUseCase(BaseProcessor):
         # CURRENT FRAME section
         human_text_lines.append(f"CURRENT FRAME @ {current_timestamp}:")
         if total_detections > 0:
+            # Vehicle categories (current frame)
             category_counts = [f"{count} {cat}" for cat, count in per_category_count.items()]
             if len(category_counts) == 1:
                 detection_text = category_counts[0] + " detected"
@@ -973,6 +1033,11 @@ class ColorDetectionUseCase(BaseProcessor):
             else:
                 detection_text = f"{', '.join(category_counts[:-1])}, and {category_counts[-1]} detected"
             human_text_lines.append(f"\t- {detection_text}")
+
+            # Colors (current frame)
+            if current_color_count:
+                color_counts_text = ", ".join([f"{count} {color}" for color, count in current_color_count.items()])
+                human_text_lines.append(f"\t- Colors: {color_counts_text}")
         else:
             human_text_lines.append(f"\t- No detections")
 
@@ -980,21 +1045,37 @@ class ColorDetectionUseCase(BaseProcessor):
 
         # TOTAL SINCE section
         human_text_lines.append(f"TOTAL SINCE {start_timestamp}:")
-        human_text_lines.append(f"\t- Total Detected: {cumulative_total}")
-        # Add category-wise counts
-        print(total_counts)
-        if total_counts:
-            for cat, count in total_counts.items():
-                if count > 0:  # Only include categories with non-zero counts
-                    human_text_lines.append(f"\t- {cat}: {count}")
+        human_text_lines.append(f"\t- Total Detected (by color): {cumulative_total}")
+        # Add category-wise totals
+        if total_category_counts_dict:
+            human_text_lines.append("\t- Categories:")
+            for cat, count in total_category_counts_dict.items():
+                if count > 0:
+                    human_text_lines.append(f"\t\t- {cat}: {count}")
+        # Add color-wise totals
+        if total_color_counts_dict:
+            human_text_lines.append("\t- Colors:")
+            for color, count in total_color_counts_dict.items():
+                if count > 0:
+                    human_text_lines.append(f"\t\t- {color}: {count}")
         # Build current_counts array in expected format  
-        current_counts = []
+        # Build arrays
+        current_counts_categories = []
         for cat, count in per_category_count.items():
-            if count > 0 or total_detections > 0:  # Include even if 0 when there are detections
-                current_counts.append({
-                    "category": cat,
-                    "count": count
-                })
+            if count > 0 or total_detections > 0:
+                current_counts_categories.append({"category": cat, "count": count})
+        current_counts_colors = []
+        for color, count in current_color_count.items():
+            if count > 0 or total_detections > 0:
+                current_counts_colors.append({"color": color, "count": count})
+        total_counts_categories = []
+        for cat, count in total_category_counts_dict.items():
+            if count > 0 or cumulative_total > 0:
+                total_counts_categories.append({"category": cat, "count": count})
+        total_counts_colors = []
+        for color, count in total_color_counts_dict.items():
+            if count > 0 or cumulative_total > 0:
+                total_counts_colors.append({"category": color, "count": count})
 
         human_text = "\n".join(human_text_lines)
 
@@ -1050,11 +1131,18 @@ class ColorDetectionUseCase(BaseProcessor):
                 }
             ]
 
-        tracking_stat=self.create_tracking_stats(total_counts=total_counts, current_counts=current_counts,
+        # Keep backward-compat: put colors into total_counts and categories into current_counts
+        tracking_stat=self.create_tracking_stats(total_counts=total_counts_colors, current_counts=current_counts_categories,
                             detections=detections, human_text=human_text, camera_info=camera_info, alerts=alerts, alert_settings=alert_settings,
                             reset_settings=reset_settings, start_time=high_precision_start_timestamp ,
                             reset_time=high_precision_reset_timestamp)
 
+        # Add explicit breakdowns for consumers who want both types
+        # tracking_stat["current_category_counts"] = current_counts_categories
+        # tracking_stat["current_color_counts"] = current_counts_colors
+        # tracking_stat["total_category_counts"] = total_counts_categories
+        # tracking_stat["total_color_counts"] = total_counts_colors
+
         tracking_stats.append(tracking_stat)
         return tracking_stats
     
